import axios from 'axios';

const api = axios.create({
    baseURL: import.meta.env.VITE_APP_BASE_API,
    timeout: 50000,
    headers: {
        'Content-Type': 'application/json'
    }
});

// 请求拦截器
api.interceptors.request.use(
    config => {
        const token = localStorage.getItem('token');
        if (token) {
            config.headers.Authorization = `Bearer ${token}`;
        }
        return config;
    },
    error => {
        return Promise.reject(error);
    }
);

// 响应拦截器
api.interceptors.response.use(
    response => {
        return response.data;
    },
    error => {
        if (error.response && error.response.status === 401) {
            // 处理未授权的情况
            // 可以在这里触发退出登录或跳转到登录页
        }
        return Promise.reject(error);
    }
);

// 封装HTTP请求方法
export const get = (url, params) => {
    return api.get(url, { params });
};

export const post = (url, data) => {
    return api.post(url, data);
};

export const put = (url, data) => {
    return api.put(url, data);
};

export const del = (url) => {
    return api.delete(url);
};

export default api;